CheckpointKeeper
================

.. currentmodule:: pykeen.checkpoints

.. autoclass:: CheckpointKeeper
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CheckpointKeeper.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
